@@ -1,6 +1,8 @@
 from io import BytesIO
 import base64
-def image_b64(image):
+from PIL import Image
+def image_b64(file):
+    image = Image.open(file)
     buffered = BytesIO()
     image.save(buffered, format="JPEG")
     image_str = base64.b64encode(buffered.getvalue())
